# Basic Properties

This page lists [detect_product_long] basic properties.
For advanced and deprecated properties, refer to [All Properties](all-properties.md).


## [bazel](detectors/bazel.md)

| Property | Description |
| --- | --- |
| [detect.bazel.path](detectors/bazel.md#bazel-executable) | <p>Bazel Executable: The path to the Bazel executable. </p>  |
| [detect.bazel.target](detectors/bazel.md#bazel-target) | <p>Bazel Target: The Bazel target (for example, //foo:foolib) for which dependencies are collected. For Detect to run Bazel, this property must be set. </p>  |
| [detect.bazel.cquery.options](detectors/bazel.md#bazel-cquery-additional-options) | <p>Bazel cquery additional options: A comma-separated list of additional options to pass to the bazel cquery command. </p>  |
| [detect.bazel.workspace.rules](detectors/bazel.md#bazel-workspace-rules) | <p>default: NONE</p> <p>Acceptable Values: ALL, NONE, MAVEN_JAR, MAVEN_INSTALL, HASKELL_CABAL_LIBRARY, HTTP_ARCHIVE </p><p>Bazel workspace rules: By default Detect discovers Bazel dependencies using all of the supported Bazel workspace rules that it finds in the WORKSPACE file. Alternatively you can use this property to specify the list of Bazel workspace rules Detect should use. </p>  |


## [binary-scanner](configuration/binary-scanner.md)

| Property | Description |
| --- | --- |
| [detect.binary.scan.file.path](configuration/binary-scanner.md#binary-scan-target) | <p>Binary Scan Target: If specified, this file and this file only will be uploaded for binary scan analysis. This property takes precedence over detect.binary.scan.file.name.patterns. The BINARY_SCAN tool does not provide project and version name defaults to Detect, so you need to set project and version names via properties when only the BINARY_SCAN tool is invoked. </p>  |
| [detect.binary.scan.file.name.patterns](configuration/binary-scanner.md#binary-scan-filename-patterns) | <p>Binary Scan Filename Patterns: If specified, files in the source directory whose names match these file name patterns will be zipped and uploaded for binary scan analysis. This property will not be used if detect.binary.scan.file.path is specified. Search depth is controlled by property detect.binary.scan.search.depth. Directories specified via property detect.excluded.directories are excluded from the file search. This property accepts filename globbing-style wildcards. Refer to the <i>Configuring Black Duck Detect</i> > <i>Property wildcard support</i> page for more details. </p>  |
| [detect.binary.scan.search.depth](configuration/binary-scanner.md#binary-scan-search-depth) | <p>default: 0</p><p>Binary Scan Search Depth: When binary scan filename patterns are being used to search for binary files to scan, this property sets the depth at which Detect will search for files (that match those patterns) to upload for binary scan analysis. </p>  |


## [bitbake](detectors/bitbake.md)

| Property | Description |
| --- | --- |
| [detect.bitbake.build.env.name](detectors/bitbake.md#bitbake-init-script-name) | <p>default: oe-init-build-env</p><p>BitBake Init Script Name: The name of the build environment init script. </p>  |
| [detect.bitbake.package.names](detectors/bitbake.md#bitbake-package-names) | <p>BitBake Package Names: A comma-separated list of package names from which dependencies are extracted. </p>  |
| [detect.bitbake.source.arguments](detectors/bitbake.md#bitbake-source-arguments) | <p>BitBake Source Arguments: A comma-separated list of arguments to supply when sourcing the build environment init script. </p>  |
| [detect.bitbake.search.depth](detectors/bitbake.md#bitbake-search-depth) | <p>default: 1</p><p>BitBake Search Depth: The depth at which Detect will search for files generated by Bitbake. </p>  |
| [detect.bitbake.dependency.types.excluded](detectors/bitbake.md#bitbake-excluded-dependency-types) | <p>default: NONE</p> <p>Acceptable Values: NONE, BUILD </p><p>Bitbake Excluded Dependency Types: The dependency types to exclude from the results. </p>  |


## [blackduck-server](configuration/blackduck-server.md)

| Property | Description |
| --- | --- |
| [blackduck.api.token](configuration/blackduck-server.md#black-duck-api-token) | <p>Black Duck API Token: The access token used to authenticate with the Black Duck Server. </p>  |
| [blackduck.offline.mode](configuration/blackduck-server.md#offline-mode) | <p>default: false</p><p>Offline Mode: This can disable Black Duck communication - if set to true, Detect will not upload BDIO files, or check policies, and it will not download and install the signature scanner. Note that the path to a local instance of the scanner can be provided using the -detect.blackduck.signature.scanner.local.path parameter. </p>  |
| [blackduck.url](configuration/blackduck-server.md#black-duck-url) | <p>Black Duck URL: URL of the Black Duck server. </p>  |
| [detect.test.connection](configuration/blackduck-server.md#test-connection-to-black-duck) | <p>default: false</p><p>Test Connection to Black Duck: Test the connection to Black Duck with the current configuration. </p>  |
| [blackduck.offline.mode.force.bdio](configuration/blackduck-server.md#force-offline-bdio-generation) | <p>default: false</p><p>Force Offline BDIO Generation: This property will force Detect in offline mode to generate a BDIO even if no code locations were identified. </p>  |


## [cleanup](configuration/cleanup.md)

| Property | Description |
| --- | --- |
| [detect.cleanup](configuration/cleanup.md#cleanup-output) | <p>default: true</p><p>Cleanup Output: If true, the files created by Detect will be cleaned up. </p>  |


## [conan](detectors/conan.md)

| Property | Description |
| --- | --- |
| [detect.conan.path](detectors/conan.md#conan-executable) | <p>Conan Executable: The path to the conan executable. </p>  |
| [detect.conan.dependency.types.excluded](detectors/conan.md#conan-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, BUILD </p><p>Conan Dependency Types Excluded: Set this value to indicate which Conan dependency types Detect should exclude from the BOM. </p>  |
| [detect.conan.arguments](detectors/conan.md#additional-conan-arguments) | <p>Additional Conan Arguments: A space-separated list of additional arguments to add to the 'conan info' command line when running Detect against a Conan project. Detect will execute the command 'conan info {additional arguments} .' </p>  |
| [detect.conan.lockfile.path](detectors/conan.md#conan-lockfile) | <p>Conan Lockfile: The path to the conan lockfile to apply when running 'conan info' to get the dependency graph. </p>  |
| [detect.conan.attempt.package.revision.match](detectors/conan.md#attempt-package-revision-match) | <p>default: false</p><p>Attempt Package Revision Match: If package revisions are available (a Conan lock file is found or provided, and Conan's revisions feature is enabled), require that each dependency's package revision match the package revision of the component in the KB. </p>  |


## [conda](detectors/conda.md)

| Property | Description |
| --- | --- |
| [detect.conda.environment.name](detectors/conda.md#anaconda-environment-name) | <p>Anaconda Environment Name: The name of the anaconda environment used by your project. </p>  |
| [detect.conda.path](detectors/conda.md#conda-executable) | <p>Conda Executable: The path to the conda executable. </p>  |


## [container-scanner](configuration/container-scanner.md)

| Property | Description |
| --- | --- |
| [detect.container.scan.file.path](configuration/container-scanner.md#container-scan-target) | <p>Container Scan Target: If specified, this file and this file only will be uploaded for container scan analysis. The CONTAINER_SCAN tool does not provide project and version name defaults to Detect, so you need to set project and version names via properties when only the CONTAINER_SCAN tool is invoked. </p>  |


## [cpan](detectors/cpan.md)

| Property | Description |
| --- | --- |
| [detect.cpan.path](detectors/cpan.md#cpan-executable) | <p>cpan Executable: The path to the cpan executable. </p>  |
| [detect.cpanm.path](detectors/cpan.md#cpanm-executable) | <p>cpanm Executable: The path to the cpanm executable. </p>  |


## [dart](detectors/dart.md)

| Property | Description |
| --- | --- |
| [detect.dart.path](detectors/dart.md#dart-executable) | <p>dart Executable: The path to the dart executable. </p>  |
| [detect.flutter.path](detectors/dart.md#flutter-executable) | <p>flutter Executable: The path to the flutter executable. </p>  |
| [detect.pub.dependency.types.excluded](detectors/dart.md#dart-pub-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Dart Pub Dependency Types Excluded: Set this value to indicate which Dart pub dependency types Detect should exclude from the BOM. </p>  |


## [debug](configuration/debug.md)

| Property | Description |
| --- | --- |
| [detect.diagnostic](configuration/debug.md#diagnostic-mode) | <p>default: false</p><p>Diagnostic Mode: When enabled, diagnostic mode collects files valuable for troubleshooting (logs, BDIO file, extraction files, reports, etc.), writes them to a zip file, and logs the path to the zip file. </p>  |


## [detector](configuration/detector.md)

| Property | Description |
| --- | --- |
| [detect.required.detector.types](configuration/detector.md#required-detect-types) |  <p>Acceptable Values: BITBAKE, CARGO, CARTHAGE, COCOAPODS, CONAN, CONDA, CPAN, CRAN, DART, GIT, GO_MOD, GO_DEP, GO_VNDR, GO_VENDOR, GO_GRADLE, GRADLE, HEX, IVY, LERNA, MAVEN, NPM, NUGET, PACKAGIST, PEAR, PIP, PNPM, POETRY, RUBYGEMS, SBT, SETUPTOOLS, SWIFT, YARN, CLANG, XCODE, OPAM </p><p>Required Detect Types: The set of required detectors. </p>  |


## [docker](detectors/docker.md)

| Property | Description |
| --- | --- |
| [detect.docker.image](detectors/docker.md#docker-image-name) | <p>Docker Image Name: The Docker image name (repo:tag) to inspect. </p>  |
| [detect.docker.image.id](detectors/docker.md#docker-image-id) | <p>Docker Image ID: The ID (shown in the 'IMAGE ID' column of 'docker images' output) of the target Docker image. The target image must already be local (must appear in the output of 'docker images'). </p>  |
| [detect.docker.path](detectors/docker.md#docker-executable) | <p>Docker Executable: Path to the docker executable (used to load image inspector Docker images in order to run the Docker Inspector in air gap mode). </p>  |
| [detect.docker.tar](detectors/docker.md#image-archive-file) | <p>Image Archive File: An image .tar file which is either a Docker image saved to a file using the 'docker save' command, or an Open Container Initiative (OCI) image .tar file. The file must be readable by all. </p>  |


## [general](configuration/general.md)

| Property | Description |
| --- | --- |
| [detect.component.location.analysis.enabled](configuration/general.md#component-location-analysis-enabled) | <p>default: false</p><p>Component Location Analysis Enabled: If set to true, Detect will save an output file named 'components-with-locations.json' in the Scan subdirectory detailing where in the project's source code OSS components are declared. </p>  |
| [detect.component.location.analysis.status](configuration/general.md#component-location-analysis-status) | <p>default: false</p><p>Component Location Analysis Status: If set to true, Detect status and exit code will be affected by the status of the Component Location Analysis run. </p>  |
| [detect.target.type](configuration/general.md#detect-target) | <p>default: SOURCE</p> <p>Acceptable Values: SOURCE, IMAGE </p><p>Detect Target: Informs detect of what is being scanned which allows improved user experience when scanning different types of targets. </p>  |
| [detect.wait.for.results](configuration/general.md#wait-for-results) | <p>default: false</p><p>Wait For Results: If set to true, Detect will wait for Black Duck products until results are available or the detect.timeout is exceeded. </p>  |
| [detect.follow.symbolic.links](configuration/general.md#follow-symbolic-links) | <p>default: true</p><p>Follow Symbolic Links: If set to true, Detect will follow symbolic links when searching for detectors, when searching for files that select detectors (such as Bitbake and Sbt) need, when searching for directories to exclude from signature scan, and when searching for binary scan targets.  Symbolic links are not supported for Impact Analysis. </p>  |
| [detect.blackduck.correlated.scanning.enabled](configuration/general.md#correlated-scanning-enabled) | <p>default: false</p><p>Correlated Scanning Enabled: When enabled, Detect activates the Black Duck correlated scanning capability to enhance match accuracy. </p>  |


## [go](detectors/go.md)

| Property | Description |
| --- | --- |
| [detect.go.path](detectors/go.md#go-executable) | <p>Go Executable: Path to the Go executable. </p>  |
| [detect.go.mod.dependency.types.excluded](detectors/go.md#go-mod-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, UNUSED, VENDORED </p><p>Go Mod Dependency Types Excluded: Set this value to indicate which Go Mod dependency types Detect should exclude from the BOM. </p>  |


## [gradle](detectors/gradle.md)

| Property | Description |
| --- | --- |
| [detect.gradle.build.command](detectors/gradle.md#gradle-build-command) | <p>Gradle Build Command: Gradle command line arguments to add to the gradle/gradlew command line. </p>  |
| [detect.gradle.configuration.types.excluded](detectors/gradle.md#gradle-configuration-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, UNRESOLVED </p><p>Gradle Configuration Types Excluded: Set this value to indicate which Gradle configuration types Detect should exclude from the BOM. </p>  |
| [detect.gradle.path](detectors/gradle.md#gradle-executable) | <p>Gradle Executable: The path to the Gradle executable (gradle or gradlew). </p>  |


## [hex](detectors/hex.md)

| Property | Description |
| --- | --- |
| [detect.hex.rebar3.path](detectors/hex.md#rebar3-executable) | <p>Rebar3 Executable: The path to the rebar3 executable. </p>  |


## [iac-scan](configuration/iac-scan.md)

| Property | Description |
| --- | --- |
| [detect.iac.scan.paths](configuration/iac-scan.md#iac-scan-target-paths) | <p>IaC Scan Target Paths: A comma-separated list of paths to perform IaC scans on. </p>  |
| [detect.iac.scan.arguments](configuration/iac-scan.md#iac-scan-arguments) | <p>IaC Scan Arguments: A space-separated list of additional arguments to use when running the IaC Scanner. </p>  |
| [detect.iac.scanner.local.path](configuration/iac-scan.md#iac-scanner-local-path) | <p>IaC Scanner Local Path: Use this property to specify the path to a local IaC Scanner. </p>  |


## [impact-analysis](configuration/impact-analysis.md)

| Property | Description |
| --- | --- |
| [detect.impact.analysis.enabled](configuration/impact-analysis.md#vulnerability-impact-analysis-enabled) | <p>default: false</p><p>Vulnerability Impact Analysis Enabled: If set to true, Detect will attempt to look for *.class files and generate a Vulnerability Impact Analysis Report for upload to Black Duck. </p>  |
| [detect.impact.analysis.output.path](configuration/impact-analysis.md#impact-analysis-output-directory) | <p>Impact Analysis Output Directory: The path to the output directory for Impact Analysis reports. </p>  |


## [lerna](detectors/lerna.md)

| Property | Description |
| --- | --- |
| [detect.lerna.path](detectors/lerna.md#lerna-executable) | <p>Lerna Executable: Path of the lerna executable. </p>  |
| [detect.lerna.package.types.excluded](detectors/lerna.md#lerna-package-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, PRIVATE </p><p>Lerna Package Types Excluded: Set this value to indicate which Lerna package types Detect should exclude from the BOM. </p>  |


## [logging](configuration/logging.md)

| Property | Description |
| --- | --- |
| [logging.level.detect](configuration/logging.md#logging-level) | <p>default: INFO</p> <p>Acceptable Values: OFF, ERROR, WARN, INFO, DEBUG, TRACE </p><p>Logging Level: The logging level of Detect. </p>  |


## [maven](detectors/maven.md)

| Property | Description |
| --- | --- |
| [detect.maven.build.command](detectors/maven.md#maven-build-command) | <p>Maven Build Command: Maven command line arguments to add to the mvn/mvnw command line. </p>  |
| [detect.maven.path](detectors/maven.md#maven-executable) | <p>Maven Executable: The path to the Maven executable (mvn or mvnw). </p>  |
| [detect.maven.included.scopes](detectors/maven.md#dependency-scope-included) | <p>Dependency Scope Included: A comma separated list of Maven scopes. Output will be limited to dependencies within these scopes (overridden by exclude). </p>  |
| [detect.maven.excluded.scopes](detectors/maven.md#dependency-scope-excluded) | <p>Dependency Scope Excluded: A comma separated list of Maven scopes. Output will be limited to dependencies outside these scopes (overrides include). </p>  |
| [detect.maven.include.shaded.dependencies](detectors/maven.md#include-shaded-dependencies) | <p>default: false</p><p>Include Shaded Dependencies: If set to true, Detect will include shaded dependencies as part of BOM. </p>  |


## [npm](detectors/npm.md)

| Property | Description |
| --- | --- |
| [detect.npm.arguments](detectors/npm.md#additional-npm-command-arguments) | <p>Additional NPM Command Arguments: A space-separated list of additional arguments that Detect will add at then end of the npm ls command line when Detect executes the NPM CLI Detector on an NPM project. </p>  |
| [detect.npm.dependency.types.excluded](detectors/npm.md#npm-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV, PEER </p><p>Npm Dependency Types Excluded: Set this value to indicate which Npm dependency types Detect should exclude from the BOM. </p>  |
| [detect.npm.path](detectors/npm.md#npm-executable) | <p>NPM Executable: The path to the Npm executable. </p>  |


## [nuget](detectors/nuget.md)

| Property | Description |
| --- | --- |
| [detect.nuget.config.path](detectors/nuget.md#nuget-config-file) | <p>Nuget Config File: The path to the Nuget.Config file to supply to the nuget exe. </p>  |
| [detect.nuget.packages.repo.url](detectors/nuget.md#nuget-packages-repository-url) | <p>default: https://api.nuget.org/v3/index.json</p><p>Nuget Packages Repository URL: The source for nuget packages </p>  |
| [detect.nuget.dependency.types.excluded](detectors/nuget.md#nuget-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Nuget Dependency Types Excluded: Set this value to indicate which Nuget dependency types Detect should exclude from the BOM. </p>  |


## [opam](detectors/opam.md)

| Property | Description |
| --- | --- |
| [detect.opam.path](detectors/opam.md#opam-executable) | <p>Opam Executable: The path to the opam executable. </p>  |


## [packagist](detectors/packagist.md)

| Property | Description |
| --- | --- |
| [detect.packagist.dependency.types.excluded](detectors/packagist.md#packagist-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Packagist Dependency Types Excluded: Set this value to indicate which Packagist dependency types Detect should exclude from the BOM. </p>  |


## [paths](configuration/paths.md)

| Property | Description |
| --- | --- |
| [detect.bash.path](configuration/paths.md#bash-executable) | <p>Bash Executable: Path to the Bash executable. </p>  |
| [detect.bdio.output.path](configuration/paths.md#bdio-output-directory) | <p>BDIO Output Directory: The path to the output directory for the generated BDIO file. </p>  |
| [detect.bdio.file.name](configuration/paths.md#bdio-file-name) | <p>BDIO File Name: The desired file name of BDIO file Detect produces in the BDIO Output Directory. </p>  |
| [detect.detector.search.depth](configuration/paths.md#detector-search-depth) | <p>default: 0</p><p>Detector Search Depth: Depth of subdirectories within the source directory to which Detect will search for files that indicate whether a detector applies. </p>  |
| [detect.git.path](configuration/paths.md#git-executable) | <p>Git Executable: Path of the git executable </p>  |
| [detect.java.path](configuration/paths.md#java-executable) | <p>Java Executable: Path to the Java executable used by Docker Inspector. </p>  |
| [detect.output.path](configuration/paths.md#detect-output-path) | <p>Detect Output Path: The path to the output directory. </p>  |
| [detect.scan.output.path](configuration/paths.md#scan-output-path) | <p>Scan Output Path: The output directory for all signature scanner output files. If not set, the signature scanner output files will be in a 'scan' subdirectory of the output directory. </p>  |
| [detect.source.path](configuration/paths.md#source-path) | <p>Source Path: The source path is the path to the project directory to inspect. If no value is provided, the source path defaults to the current working directory. </p>  |
| [detect.tools.excluded](configuration/paths.md#detect-tools-excluded) |  <p>Acceptable Values: NONE, DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, DOCKER, BAZEL, IAC_SCAN, CONTAINER_SCAN, THREAT_INTEL, COMPONENT_LOCATION_ANALYSIS </p><p>Detect Tools Excluded: The tools Detect should not allow, in a comma-separated list. Excluded tools will not be run even if all criteria for the tool is met. Exclusion rules always take precedence. </p>  |
| [detect.tools](configuration/paths.md#detect-tools-included) |  <p>Acceptable Values: ALL, DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, DOCKER, BAZEL, IAC_SCAN, CONTAINER_SCAN, THREAT_INTEL, COMPONENT_LOCATION_ANALYSIS </p><p>Detect Tools Included: The tools Detect should allow in a comma-separated list. Tools in this list (as long as they are not in the excluded list) will run if all criteria of the tool are met. Exclusion rules always take precedence. </p>  |
| [detect.status.json.output.path](configuration/paths.md#status-json-output-path) | <p>Status JSON Output Path: The directory to place a copy of the status.json file. </p>  |
| [detect.scaaas.scan.path](configuration/paths.md#scaaas-scan-target) | <p>SCAAAS Scan Target: Internal use only. Specified file will be uploaded to the BDBA worker for scan analysis in an SCA as a service environment. </p>  |


## [pear](detectors/pear.md)

| Property | Description |
| --- | --- |
| [detect.pear.dependency.types.excluded](detectors/pear.md#pear-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, OPTIONAL </p><p>Pear Dependency Types Excluded: Set this value to indicate which Pear dependency types Detect should exclude from the BOM. </p>  |
| [detect.pear.path](detectors/pear.md#pear-executable) | <p>Pear Executable: The path to the pear executable. </p>  |


## [pip](detectors/pip.md)

| Property | Description |
| --- | --- |
| [detect.pipfile.dependency.types.excluded](detectors/pip.md#pipfile-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Pipfile Dependency Types Excluded: A comma-separated list of dependency types that will be excluded. </p>  |
| [detect.pip.project.name](detectors/pip.md#pip-project-name) | <p>PIP Project Name: The name of your PIP project, to be used if your project's name cannot be correctly inferred from its setup.py file. </p>  |
| [detect.pip.project.version.name](detectors/pip.md#pip-project-version-name) | <p>PIP Project Version Name: The version of your PIP project, to be used if your project's version name cannot be correctly inferred from its setup.py file. </p>  |
| [detect.pip.requirements.path](detectors/pip.md#pip-requirements-path) | <p>PIP Requirements Path: A comma-separated list of paths to requirements files, to be used to analyze requirements files with a filename other than requirements.txt or to specify which requirements files should be analyzed. </p>  |
| [detect.pip.only.project.tree](detectors/pip.md#pip-include-only-project-tree) | <p>default: false</p><p>PIP Include Only Project Tree: By default, pipenv includes all dependencies found in the graph. Set to true to only include dependencies found underneath the dependency that matches the provided pip project and version name. </p>  |
| [detect.pip.path](detectors/pip.md#pip-executable) | <p>Pip Executable: The path to the Pip executable. </p>  |
| [detect.pipenv.path](detectors/pip.md#pipenv-executable) | <p>Pipenv Executable: The path to the Pipenv executable. </p>  |


## [pnpm](detectors/pnpm.md)

| Property | Description |
| --- | --- |
| [detect.pnpm.dependency.types.excluded](detectors/pnpm.md#pnpm-dependency-types) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV, OPTIONAL </p><p>pnpm Dependency Types: Set this value to indicate which pnpm dependency types Detect should exclude from the BOM. </p>  |


## [poetry](detectors/poetry.md)

| Property | Description |
| --- | --- |
| [detect.poetry.dependency.groups.excluded](detectors/poetry.md#poetry-dependency-groups) | <p>Poetry dependency groups: Set this value to indicate which Poetry dependency groups Detect should exclude from the BOM. </p>  |


## [project](configuration/project.md)

| Property | Description |
| --- | --- |
| [detect.policy.check.fail.on.severities](configuration/project.md#fail-on-policy-violation-severities) | <p>default: NONE</p> <p>Acceptable Values: ALL, NONE, BLOCKER, CRITICAL, MAJOR, MINOR, OK, TRIVIAL, UNSPECIFIED </p><p>Fail on Policy Violation Severities: A comma-separated list of policy violation severities that will fail Detect. If this is set to NONE, Detect will not fail due to policy violations. A value of ALL is equivalent to all of the other possible values except NONE. </p>  |
| [detect.policy.check.fail.on.names](configuration/project.md#fail-on-policy-names-with-violations) | <p>Fail on Policy Names with Violations: A comma-separated list of policy names with a non-zero number of violations that will fail Detect. </p>  |
| [detect.project.description](configuration/project.md#project-description) | <p>Project Description: If project description is specified, your project will be created with this description. For updates, see detect.project.version.update. </p>  |
| [detect.project.name](configuration/project.md#project-name) | <p>Project Name: An override for the name to use for the Black Duck project. If not supplied, Detect will attempt to use the tools to figure out a reasonable project name. If that fails, the final part of the directory path where the inspection is taking place will be used. </p>  |
| [detect.project.tier](configuration/project.md#project-tier) | <p>Project Tier: If a Black Duck project tier is specified, your project will be created with this tier. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.name](configuration/project.md#version-name) | <p>Version Name: An override for the version to use for the Black Duck project. If not supplied, Detect will attempt to use the tools to figure out a reasonable version name. If that fails, the current date will be used. </p>  |
| [detect.project.version.nickname](configuration/project.md#version-nickname) | <p>Version Nickname: If a project version nickname is specified, your project version will be created with this nickname. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.notes](configuration/project.md#version-notes) | <p>Version Notes: If project version notes are specified, your project version will be created with these notes. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.phase](configuration/project.md#version-phase) | <p>default: DEVELOPMENT</p> <p>Acceptable Values: ARCHIVED, DEPRECATED, DEVELOPMENT, PLANNING, PRERELEASE, RELEASED </p><p>Version Phase: If project version phase is specified, your project version will be created with this phase. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.update](configuration/project.md#update-project-version) | <p>default: false</p><p>Update Project Version: If set to true, Detect will update the Black Duck project and project version according to configured project and project version properties. (By default, these properties are only set on created projects / project versions.) </p>  |
| [detect.project.version.license](configuration/project.md#project-version-license) | <p>Project Version License: If project version license is specified, your project version will be created with this license. For updates, see detect.project.version.update. </p>  |


## [python](detectors/python.md)

| Property | Description |
| --- | --- |
| [detect.python.path](detectors/python.md#python-executable) | <p>Python Executable: The path to the Python executable. </p>  |


## [report](configuration/report.md)

| Property | Description |
| --- | --- |
| [detect.notices.report](configuration/report.md#generate-notices-report) | <p>default: false</p><p>Generate Notices Report: When set to true, a Black Duck notices report in text form will be created in your source directory. </p>  |
| [detect.notices.report.path](configuration/report.md#notices-report-path) | <p>Notices Report Path: The output directory for notices report. Default is the source directory. </p>  |
| [detect.risk.report.pdf](configuration/report.md#generate-risk-report-40pdf41) | <p>default: false</p><p>Generate Risk Report (PDF): When set to true, a Black Duck risk report in PDF form will be created. </p>  |
| [detect.risk.report.pdf.path](configuration/report.md#risk-report-output-path) | <p>Risk Report Output Path: The output directory for risk report in PDF. Default is the source directory. </p>  |


## [ruby](detectors/ruby.md)

| Property | Description |
| --- | --- |
| [detect.ruby.dependency.types.excluded](detectors/ruby.md#ruby-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, RUNTIME, DEV </p><p>Ruby Dependency Types Excluded: Set this value to indicate which Ruby(Gempsec) dependency types Detect should exclude from the BOM. </p>  |


## [sbt](detectors/sbt.md)

| Property | Description |
| --- | --- |
| [detect.sbt.path](detectors/sbt.md#sbt-executable) | <p>Sbt Executable: Path to the Sbt executable. </p>  |
| [detect.sbt.arguments](detectors/sbt.md#additional-sbt-command-arguments) | <p>Additional sbt command Arguments: A space-separated list of additional arguments to add to sbt command line when running Detect against an SBT project. Detect will execute the command 'sbt {additional arguments} {Detect-added arguments}'. </p>  |


## [signature-scanner](configuration/signature-scanner.md)

| Property | Description |
| --- | --- |
| [detect.blackduck.signature.scanner.arguments](configuration/signature-scanner.md#signature-scanner-arguments) | <p>Signature Scanner Arguments: A space-separated list of additional arguments to use when running the Black Duck signature scanner. Key-value pairs specified as arguments will replace the same entries specifed elswhere. Available signature scanner properties can be determined by specifying '--help' when executing the signature scanner jar file from the command line. </p>  |
| [detect.blackduck.signature.scanner.copyright.search](configuration/signature-scanner.md#signature-scanner-copyright-search) | <p>default: false</p><p>Signature Scanner Copyright Search: When set to true, user will be able to scan and discover copyright names in Black Duck. Corresponding Signature Scanner CLI Argument: --copyright-search. </p>  |
| [detect.blackduck.signature.scanner.csv.archive](configuration/signature-scanner.md#signature-scanner-csv-archive-output) | <p>default: false</p><p>Signature Scanner CSV Archive Output: When set to true Signature Scanner output will be in CSV format. Corresponding Signature Scanner CLI Argument: --outputFormat csv for offline mode, --upload-csv for online mode. </p>  |
| [detect.blackduck.signature.scanner.dry.run](configuration/signature-scanner.md#signature-scanner-dry-run) | <p>default: false</p><p>Signature Scanner Dry Run: If set to true, the signature scanner results are not uploaded to Black Duck, and the scanner results are written to disk via the Signature Scanner CLI argument: --dryRunWriteDir. </p>  |
| [detect.blackduck.signature.scanner.individual.file.matching](configuration/signature-scanner.md#individual-file-matching) | <p>default: NONE</p> <p>Acceptable Values: NONE, SOURCE, BINARY, ALL </p><p>Individual File Matching: Users may set this property to indicate what types of files they want to match. Corresponding Signature Scanner CLI Argument: --individualFileMatching. </p>  |
| [detect.blackduck.signature.scanner.license.search](configuration/signature-scanner.md#signature-scanner-license-search) | <p>default: false</p><p>Signature Scanner License Search: When set to true, user will be able to scan and discover license names in Black Duck. Corresponding Signature Scanner CLI Argument: --license-search. </p>  |
| [detect.blackduck.signature.scanner.local.path](configuration/signature-scanner.md#signature-scanner-local-path) | <p>Signature Scanner Local Path: To use a local signature scanner, specify the path where the signature scanner was unzipped. This will likely look similar to 'scan.cli-x.y.z' and includes the 'bin, icon, jre, and lib' directories of the expanded scan.cli. </p>  |
| [detect.blackduck.signature.scanner.paths](configuration/signature-scanner.md#signature-scanner-target-paths) | <p>Signature Scanner Target Paths: If this property is not set, the signature scanner target path is the source path (see property detect.source.path). If this property is set, the paths provided in this property's value will be signature scanned instead (the signature scanner will be executed once for each provided path). </p>  |
| [detect.blackduck.signature.scanner.snippet.matching](configuration/signature-scanner.md#snippet-matching) | <p>default: NONE</p> <p>Acceptable Values: NONE, SNIPPET_MATCHING, SNIPPET_MATCHING_ONLY </p><p>Snippet Matching: Use this value to enable the various snippet scanning modes. For a full explanation, please refer to the 'Running a component scan using the Signature Scanner command line' section in your Black Duck server's online help. Corresponding Signature Scanner CLI Arguments: --snippet-matching, --snippet-matching-only, --full-snippet-scan. </p>  |
| [detect.blackduck.signature.scanner.reduced.persistence](configuration/signature-scanner.md#reduced-persistence) | <p>default: DEFAULT</p> <p>Acceptable Values: DEFAULT, RETAIN_UNMATCHED, DISCARD_UNMATCHED </p><p>Reduced Persistence: Use this value to control how unmatched files from signature scans are stored. For a full explanation, please refer to <xref href="https://documentation%2Eblackduck%2Ecom/bundle/bd%2Dhub/page/ComponentDiscovery/about%5Freduced%5Fpersistence%5Fsignature%5Fscanning%2Ehtml" scope="external" outputclass="external" format="html" target="_blank">about reduced persistence signature scanning.</xref> </p>  |
| [detect.blackduck.signature.scanner.upload.source.mode](configuration/signature-scanner.md#upload-source-mode) | <p>default: false</p><p>Upload source mode: If set to true, the signature scanner will, if supported by your Black Duck version, upload source code to Black Duck. Corresponding Signature Scanner CLI Argument: --upload-source. </p>  |
| [detect.excluded.directories.search.depth](configuration/signature-scanner.md#detect-excluded-directories-search-depth) | <p>default: 4</p><p>Detect Excluded Directories Search Depth: Enables you to adjust the depth to which Detect will search when creating signature scanner exclusion patterns. </p>  |


## [swift](detectors/swift.md)

| Property | Description |
| --- | --- |
| [detect.swift.path](detectors/swift.md#swift-executable) | <p>Swift Executable: Path of the swift executable. </p>  |


## [threat-intel](configuration/threat-intel.md)

| Property | Description |
| --- | --- |
| [detect.threatintel.scan.file.path](configuration/threat-intel.md#threat-intel-scan-target) | <p>Threat Intel Scan Target: If specified, this file and this file only will be uploaded for Threat Intel analysis.  The THREAT_INTEL tool does not provide project and version name defaults to Detect, so you need to set project and version names via properties when only the THREAT_INTEL tool is invoked. </p>  |


## [yarn](detectors/yarn.md)

| Property | Description |
| --- | --- |
| [detect.yarn.ignore.all.workspaces](detectors/yarn.md#ignore-all-workspaces) | <p>default: false</p><p>Ignore All Workspaces: All workspaces are ignored by the Yarn detector for increased performance and precision to scan a massive codebase. </p>  |
| [detect.yarn.dependency.types.excluded](detectors/yarn.md#yarn-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, NON_PRODUCTION </p><p>Yarn Dependency Types Excluded: Set this value to indicate which Yarn dependency types Detect should exclude from the BOM. </p>  |

